Crate nidus_sqlx

Crate nidus_sqlx 

Official SQLx adapter for Nidus applications.

This crate is installed separately from the core nidus facade so SQLx dependencies are only compiled by applications that choose this adapter.

Enums

SqlxError
Error returned by SQLx adapter operations.

Type Aliases

Result
Result type used by SQLx adapter operations.